@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: macro.py 81271 2007-10-31 14:32:43Z berndroessl $
+$Id: macro.py 92795 2008-11-05 15:04:01Z jukart $
 """
 __docformat__ = "reStructuredText"
 
@@ -41,9 +41,17 @@ class Macro(object):
                                                 self.request,
                                                 options=kwargs)
         context = self.template.pt_getEngineContext(namespace)
-        TALInterpreter(program, None,
-                       context, output, tal=True, showtal=False,
-                       strictinsert=0, sourceAnnotations=False)()
+        debug_flags = self.request.debug
+        TALInterpreter(
+                program,
+                None,
+                context,
+                output,
+                tal=True,
+                showtal=getattr(debug_flags, 'showTAL', 0),
+                strictinsert=0,
+                sourceAnnotations=getattr(debug_flags, 'sourceAnnotations', 0),
+                )()
         if not self.request.response.getHeader("Content-Type"):
             self.request.response.setHeader("Content-Type",
                                             self.contentType)
